@@ -14,7 +14,7 @@ import pyresdev.utils.data_engineering_functions as DEutils
 
 logger = logging.getLogger(__name__)
 
-__all__ = ['preprocessing_training', 'preprocessing_predictions']
+__all__ = ['preprocessing_training']
 
 
 def preprocessing_training_common(df, config, model_type, mapping_dicts=None, imp=None):
